import React from 'react';
import {
  Table,
  Col,
  Row,
  Input,
  Select,
  TimePicker,
  Form,
  Button
} from 'antd';
import type { ColumnsType } from 'antd/es/table';
import './index.css'

interface dataFilterType {
  index: string,
  label: string,
  component: string,
}

interface TablePlusProps {
  dataSource: any[],
  columns: ColumnsType<any>,
  dataFilter?: dataFilterType[],
}

const TablePlus: React.FC<TablePlusProps> = (props: TablePlusProps) => {
  const { dataSource, columns, dataFilter, ...rest } = props;
  const Elements = (key:string) => {
    switch (key) {
      case 'Input': return <Input />;
      case 'Select': return <Select />;
      case 'TimePicker': return <TimePicker />;
    }
  }

  const DataFilter = () => {
    return <Col>
      <Form
        labelCol={{ span: 8 }}
        wrapperCol={{ span: 16 }}
        layout="inline"
      >
        {dataFilter?.map((item: dataFilterType) => {
          return <Form.Item key={item.index} name={item.index} label={item.label}>
            {Elements(item.component)}
          </Form.Item>
        })}
        <Form.Item>
          <Button type="primary">Submit</Button>
        </Form.Item>
        <Form.Item>
          <Button>Reset</Button>
        </Form.Item>
      </Form>
    </Col>
  }
  return (
    <div className='table-plus-layout'>
      <Row gutter={[0, 24]}>
        {dataFilter?.length && <DataFilter />}
        <Col span={24}>
          <Table
            dataSource={dataSource}
            columns={columns}
            {...rest}
          />
        </Col>
      </Row>
    </div>
  )
}

export default TablePlus;
